@@ -5,6 +5,7 @@ Data Transformers
 
 from .base_data_transformer import BaseDataTransformer
 from .boxcox import BoxCox
+from .diff import Diff
 from .fittable_data_transformer import FittableDataTransformer
 from .invertible_data_transformer import InvertibleDataTransformer
 from .mappers import InvertibleMapper, Mapper
@@ -16,3 +17,4 @@ from .reconciliation import (
 )
 from .scaler import Scaler
 from .static_covariates_transformer import StaticCovariatesTransformer
+from .window_transformer import WindowTransformer
