@@ -9,14 +9,14 @@ import numpy as np
 import statsmodels.tsa.holtwinters as hw
 
 from darts.logging import get_logger
-from darts.models.forecasting.forecasting_model import ForecastingModel
+from darts.models.forecasting.forecasting_model import LocalForecastingModel
 from darts.timeseries import TimeSeries
 from darts.utils.utils import ModelMode, SeasonalityMode
 
 logger = get_logger(__name__)
 
 
-class ExponentialSmoothing(ForecastingModel):
+class ExponentialSmoothing(LocalForecastingModel):
     def __init__(
         self,
         trend: Optional[ModelMode] = ModelMode.ADDITIVE,
@@ -85,6 +85,7 @@ class ExponentialSmoothing(ForecastingModel):
 
     def fit(self, series: TimeSeries):
         super().fit(series)
+        self._assert_univariate(series)
         series = self.training_series
 
         # if the model was initially created with `self.seasonal_periods=None`, make sure that
@@ -116,7 +117,7 @@ class ExponentialSmoothing(ForecastingModel):
 
         return self
 
-    def predict(self, n, num_samples=1):
+    def predict(self, n, num_samples=1, verbose: bool = False):
         super().predict(n, num_samples)
 
         if num_samples == 1:
