@@ -9,12 +9,13 @@ from typing import List, Optional, Sequence, Tuple, Union
 from darts.logging import get_logger, raise_if, raise_if_not
 from darts.models.forecasting.ensemble_model import EnsembleModel
 from darts.models.forecasting.forecasting_model import (
-    ForecastingModel,
     GlobalForecastingModel,
+    LocalForecastingModel,
 )
 from darts.models.forecasting.linear_regression_model import LinearRegressionModel
 from darts.models.forecasting.regression_model import RegressionModel
 from darts.timeseries import TimeSeries
+from darts.utils.utils import seq2series, series2seq
 
 logger = get_logger(__name__)
 
@@ -22,7 +23,9 @@ logger = get_logger(__name__)
 class RegressionEnsembleModel(EnsembleModel):
     def __init__(
         self,
-        forecasting_models: Union[List[ForecastingModel], List[GlobalForecastingModel]],
+        forecasting_models: Union[
+            List[LocalForecastingModel], List[GlobalForecastingModel]
+        ],
         regression_train_n_points: int,
         regression_model=None,
     ):
@@ -88,7 +91,8 @@ class RegressionEnsembleModel(EnsembleModel):
         )
 
         # spare train_n_points points to serve as regression target
-        if self.is_single_series:
+        is_single_series = isinstance(series, TimeSeries)
+        if is_single_series:
             train_n_points_too_big = len(self.training_series) <= self.train_n_points
         else:
             train_n_points_too_big = any(
@@ -102,7 +106,7 @@ class RegressionEnsembleModel(EnsembleModel):
             logger,
         )
 
-        if self.is_single_series:
+        if is_single_series:
             forecast_training = self.training_series[: -self.train_n_points]
             regression_target = self.training_series[-self.train_n_points :]
         else:
@@ -138,9 +142,9 @@ class RegressionEnsembleModel(EnsembleModel):
         for model in self.models:
             if self.is_global_ensemble:
                 kwargs = dict(series=series)
-                if model.uses_past_covariates:
+                if model.supports_past_covariates:
                     kwargs["past_covariates"] = past_covariates
-                if model.uses_future_covariates:
+                if model.supports_future_covariates:
                     kwargs["future_covariates"] = future_covariates
                 model.fit(**kwargs)
 
@@ -154,9 +158,10 @@ class RegressionEnsembleModel(EnsembleModel):
         predictions: Union[TimeSeries, Sequence[TimeSeries]],
         series: Optional[Sequence[TimeSeries]] = None,
     ) -> Union[TimeSeries, Sequence[TimeSeries]]:
-        if self.is_single_series:
-            predictions = [predictions]
-            series = [series]
+
+        is_single_series = isinstance(series, TimeSeries) or series is None
+        predictions = series2seq(predictions)
+        series = series2seq(series) if series is not None else [None]
 
         ensembled = [
             self.regression_model.predict(
@@ -164,5 +169,4 @@ class RegressionEnsembleModel(EnsembleModel):
             )
             for serie, prediction in zip(series, predictions)
         ]
-
-        return ensembled[0] if self.is_single_series else ensembled
+        return seq2series(ensembled) if is_single_series else ensembled
