@@ -1,4 +1,5 @@
 import itertools
+import sys
 import unittest
 
 import numpy as np
@@ -102,14 +103,16 @@ class TimeSeriesWindowTransformTestCase(unittest.TestCase):
             }  # window list
             self.series_univ_det.window_transform(transforms=window_transformations)
 
-        with self.assertRaises(ValueError):
-            window_transformations = {
-                "function": "mean",
-                "window": 3,
-                "mode": "rolling",
-                "step": -2,
-            }  # Negative step
-            self.series_univ_det.window_transform(transforms=window_transformations)
+        # skip this test for Python <= 3.7
+        if sys.version_info >= (3, 8):
+            with self.assertRaises(ValueError):
+                window_transformations = {
+                    "function": "mean",
+                    "window": 3,
+                    "mode": "rolling",
+                    "step": -2,
+                }  # Negative step
+                self.series_univ_det.window_transform(transforms=window_transformations)
 
         with self.assertRaises(ValueError):
             window_transformations = {
@@ -345,6 +348,13 @@ class TimeSeriesWindowTransformTestCase(unittest.TestCase):
         )
         self.assertEqual(transformed_ts, expected_transformed_series)
 
+        # pandas on Python <= 3.7 raises this error:
+        # AttributeError: 'ExponentialMovingWindow' object has no attribute 'sum'
+
+        # skip these tests in Python <= 3.7:
+        if sys.version_info < (3, 8):
+            return
+
         transformation = [
             {"function": "sum", "mode": "rolling", "window": 1, "closed": "left"},
             {"function": "sum", "mode": "ewm", "span": 1},
