@@ -24,9 +24,18 @@ class TimeSeriesMultivariateTestCase(DartsBaseTestClass):
         },
         index=times2,
     )
+    dataframe4 = pd.DataFrame(
+        {
+            "0": [1, 1, np.nan, 1, 1, 1, 1, 1, 1, 1],
+            "1": [1, 1, np.nan, 1, 1, np.nan, np.nan, 1, 1, 1],
+            "2": [1, 1, np.nan, 1, 1, np.nan, np.nan, np.nan, np.nan, 1],
+        },
+        index=times2,
+    )
     series1 = TimeSeries.from_dataframe(dataframe1)
     series2 = TimeSeries.from_dataframe(dataframe2)
     series3 = TimeSeries.from_dataframe(dataframe3)
+    series4 = TimeSeries.from_dataframe(dataframe4)
 
     def test_creation(self):
         series_test = TimeSeries.from_dataframe(self.dataframe1)
@@ -96,6 +105,15 @@ class TimeSeriesMultivariateTestCase(DartsBaseTestClass):
     def test_append(self):
         TimeSeriesTestCase.helper_test_append(self, self.series1)
 
+    def test_append_values(self):
+        TimeSeriesTestCase.helper_test_append_values(self, self.series1)
+
+    def test_prepend(self):
+        TimeSeriesTestCase.helper_test_prepend(self, self.series1)
+
+    def test_prepend_values(self):
+        TimeSeriesTestCase.helper_test_prepend_values(self, self.series1)
+
     def test_strip(self):
         dataframe1 = pd.DataFrame(
             {
@@ -250,3 +268,39 @@ class TimeSeriesMultivariateTestCase(DartsBaseTestClass):
         seriesB = self.series1.drop_columns(["0", "1"])
         self.assertIn("2", seriesB.columns.values)
         self.assertEqual(len(seriesB.columns), 1)
+
+    def test_gaps(self):
+        gaps1_all = self.series1.gaps(mode="all")
+        self.assertTrue(gaps1_all.empty)
+        gaps1_any = self.series1.gaps(mode="any")
+        self.assertTrue(gaps1_any.empty)
+
+        gaps4_all = self.series4.gaps(mode="all")
+        self.assertTrue(
+            (
+                gaps4_all["gap_start"] == pd.DatetimeIndex([pd.Timestamp("20130208")])
+            ).all()
+        )
+        self.assertTrue(
+            (gaps4_all["gap_end"] == pd.DatetimeIndex([pd.Timestamp("20130208")])).all()
+        )
+        self.assertEqual(gaps4_all["gap_size"].values.tolist(), [1])
+
+        gaps4_any = self.series4.gaps(mode="any")
+        self.assertTrue(
+            (
+                gaps4_any["gap_start"]
+                == pd.DatetimeIndex(
+                    [pd.Timestamp("20130208"), pd.Timestamp("20130211")]
+                )
+            ).all()
+        )
+        self.assertTrue(
+            (
+                gaps4_any["gap_end"]
+                == pd.DatetimeIndex(
+                    [pd.Timestamp("20130208"), pd.Timestamp("20130214")]
+                )
+            ).all()
+        )
+        self.assertEqual(gaps4_any["gap_size"].values.tolist(), [1, 4])
